/**
 * Created by Blake on 11/13/13.
 */
angular.module('myApp',[
        'myControllers',
        'myServices',
        'myDirectives',
        'ngRoute',
        'ngAnimate',
        'ngSanitize'
    ]).
    config(['$routeProvider','$locationProvider',function($routeProvider,$locationProvider){
        $routeProvider.
            when('/',{templateUrl: 'partials/home.html',controller: 'HomeCtrl'}).
            when('/contact',{templateUrl: 'partials/contact.html',controller: 'ContactCtrl'}).
            when('/services',{templateUrl: 'partials/services.html', controller: 'ServicesCtrl'}).
            when('/pricing',{templateUrl: 'partials/pricing.html',controller: 'PricingCtrl'}).
            when('/about',{templateUrl: 'partials/about.html',controller: 'AboutCtrl'}).
            when('/get-started',{templateUrl: 'partials/get-started.html', controller: 'GetStartedCtrl'}).
            otherwise({redirectTo: '/'});
        if(window.history && window.history.pushState){
            $locationProvider.html5Mode(true);
        }
    }]);
/**
 * Created by Blake on 11/13/13.
 */
angular.module('myControllers',[]).
    controller('MainCtrl',['$scope','Page',function($scope,Page){
        $scope.Page = Page;
    }]).
    controller('HomeCtrl',['$scope','Page',function($scope,Page){
        Page.setTitle('Home');
        window.scrollTo(0,0);

        $scope.slider = [
            {file:'partials/templates/slides/slide1.html',action:'current'},
            {file:'partials/templates/slides/slide2.html'},
            {file:'partials/templates/slides/slide3.html'}
        ];

        $scope.steps = [
            {step: 1, title: "Ready", desc: "Call our office for an appointment<br><a>(707) 403-5008</a>"},
            {step: 2, title: "Set", desc: "Talk with the doctor for 30 minutes, followed up with an examination"},
            {step: 3, title: "Go", desc: "Get started with care. A positive exam shows we can help you to get started with a Sound life"}
        ];
    }]).
    controller('ContactCtrl',['$scope','Page','ApiLocal',function($scope,Page,ApiLocal){
        Page.setTitle('Contact Us');
        window.scrollTo(0,0);

        $scope.socialIcons = [];

        ApiLocal.social(function(data){
            $scope.socialIcons = data;
            console.log($scope.socialIcons[0]);
        });

    }]).
    controller('ContactFormCtrl',['$scope','ApiRemote',function($scope,ApiRemote){
        $scope.formSuccess = false;
        $scope.submitButtonTxt = "Send";
        $scope.submitButtonClass = "";
        $scope.submitLoading = false;

        $scope.submit = function(){
            if($scope.submitLoading===false){
                $scope.loading();
                ApiRemote.submit($scope.formData,function(data){
                    var success = data.type=="success";
                    console.log('success?: ',success);
                    if(success){
                        //reset form
                        $scope.formData = "";
                        $scope.formSuccess = true;
                    }else{
                        console.log("ERROR " + data.error_code + ": " + data.errorMessage);
                        alert(data.message);
                        $scope.loadingReset();
                    }
                });
            }else{
                console.log('blocked');
            }
        };

        $scope.loading = function(){
            $scope.submitButtonTxt = "Sending...";
            $scope.submitButtonClass = "loading";
            $scope.submitLoading = true;
        };

        $scope.loadingReset = function(){
            $scope.submitButtonTxt = "Submit";
            $scope.submitButtonClass = "";
            $scope.submitLoading = false;
        };
    }]).
    controller('PricingCtrl',['$scope','Page',function($scope,Page){
        Page.setTitle('Pricing');
        window.scrollTo(0,0);
    }]).
    controller('ServicesCtrl',['$scope','$anchorScroll','Page','ApiLocal',function($scope,$anchorScroll,Page,ApiLocal){
        Page.setTitle('Chiropractic Services');
        window.scrollTo(0,0);

        $scope.services = [];
        ApiLocal.services(function(data){
            $scope.services = data;
        });
    }]).
    controller('AboutCtrl',['$scope','Page',function($scope,Page){
        Page.setTitle('About Us');
        window.scrollTo(0,0);
    }]).
    controller('GetStartedCtrl',['$scope','Page',function($scope,Page){
        Page.setTitle('Get Started');
        window.scrollTo(0,0);

        $scope.steps = [
            {
                step: 1,
                title: "Contact Us",
                desc: "Call our office for an appointment, or visit our <a href='./contact'>contact</a> page for more options.<br><a><h4>(707) 403-5008</h4></a>",
                icon: 'images/icons/icon_phone_color.png'
            },
            {
                step: 2,
                title: "Come In",
                desc: "Talk with the doctor for 30 minutes, followed up with an examination",
                icon: 'images/icons/icon_chat_color.png'
            },
            {
                step: 3,
                title: "Get Results",
                desc: "Get started with care. A positive exam shows we can help you to get started with a Sound life",
                icon: 'images/icons/icon_health_color.png'
            }
        ];
    }]).
    controller('HeaderCtrl',['$scope',function($scope){
        $scope.navItems = [
            {text:'Home',link:'./home',type:'bold'},
            {text:'Services',link:'./services',type:'normal'},
            {text:'About',link:'./about',type:'normal'},
            {text:'Contact',link:'./contact',type:'normal'},
            {text:'Get Started',link:'./get-started',type:'button'}
        ];
    }]).
	controller('FooterCtrl',['$scope','ApiLocal',function($scope,ApiLocal){
        $scope.socialIcons = [];

        ApiLocal.social(function(data){
            $scope.socialIcons = data;
        });
    }]);
angular.module('myDirectives',[]).
    directive('activeLink',['$location',function(location){
        return {
            restrict: 'A',
            link: function(scope,elem,attrs,controller){
                var activeClass = attrs.activeLink;
                var path = attrs.href || attrs.ngHref;
                path = path.substring(1);
                scope.location = location;
                scope.$watch('location.path()',function(newPath){
                    if(path==newPath){
                        elem.addClass(activeClass);
                    }else{
                        elem.removeClass(activeClass);
                    }
                });
            }
        };
    }]).
    directive('header',[function(){
        return {
            restrict: 'E',
            scope: true,
            link: function(scope,elem){
                var windowEl = $(window);
                var posShow = 300;

                var handler = function(){
                    scope.scroll = windowEl.scrollTop();

                    if(scope.scroll > posShow){
                        scope.sticky = true;
                    }else{
                        scope.sticky = false;
                    }
                };
                windowEl.on('scroll',scope.$apply.bind(scope,handler));
                handler();
            }
        };
    }]).
    directive('businessHours',['ApiLocal',function(ApiLocal){
        return {
            restrict: 'E',
            templateUrl: 'partials/templates/businessHours.html',
            link: function(scope,elem){
                scope.businessHours = [];

                ApiLocal.businessHours(function(data){
                    scope.businessHours = data;
                });
            }
        };
    }]).
    directive('toggleItem',['ApiLocal',function(ApiLocal){
        return {
            restrict: 'A',
            link: function(scope,elem){
                scope.showItem = false;

                scope.toggleItem = function(){
                    scope.showItem = scope.showItem ? false : true;
                };
            }
        };
    }]).
    directive('slider',[function(){
        return {
            restrict: 'E',
            templateUrl: 'partials/templates/slider.html',
            scope: {
                options: '='
            },
            link: function(scope,elem){
                scope.currSlide = 1;
                scope.maxSlides = scope.options.slides.length;

                //set default speed
                if(typeof scope.options.speed=="undefined"){ scope.options.speed = 5; }

                scope.interval = setInterval(function(){
                    scope.nextSlide();
                    scope.$apply();
                },scope.options.speed*1000);

                scope.gotoSlide = function(index){
                    scope.currSlide = index - 1;
                    scope.moveImages();
                    clearInterval(scope.interval);
                };

                scope.gotoSlide = function(slide){
                    var prevSlide = scope.currSlide;

                    if(slide > 0 && slide <= scope.maxSlides){
                        scope.currSlide = slide;
                    }

                    var fromRight = (scope.currSlide > prevSlide);

                    scope.moveImages(fromRight,prevSlide);
                };

                scope.nextSlide = function(){
                    var prevSlide = scope.currSlide;

                    if(scope.currSlide < scope.maxSlides){
                        scope.currSlide++;
                    }else{
                        scope.currSlide = 1;
                    }
                    scope.moveImages(true,prevSlide);
                };

                scope.prevSlide = function(){
                    var prevSlide = scope.currSlide;

                    if(scope.currSlide > 1){
                        scope.currSlide--;
                    }else{
                        scope.currSlide = scope.maxSlides;
                    }
                    scope.moveImages(false,prevSlide);
                };

                scope.moveImages = function(fromRight,prevSlide){
                    clearInterval(scope.interval);

                    var moveVal = 0;
                    var slideOutAction, slideInAction;

                    if(fromRight){
                        slideOutAction = "move-out-left";
                        slideInAction = "move-in-right";
                    }else{
                        slideOutAction = "move-out-right";
                        slideInAction = "move-in-left";
                    }

                    //Animate slide going out of view
                    scope.options.slides[prevSlide - 1].action = slideOutAction;

                    //Animate slide going into view
                    scope.options.slides[scope.currSlide - 1].action = slideInAction;
                };
            }
        };
    }])
    .directive('navMenu',['$window',function($window){
        return {
            link: function(scope,elem,args){
                scope.showNav = false;

                scope.toggleNav = function(){
                    $window.onclick = null;

                    if(scope.showNav===false){
                        scope.showNav = true;
                        $window.onclick = function(event){
                            scope.showNav = false;
                            scope.$apply();
                            $window.onclick = null;
                        };
                    }else{
                        scope.showNav = false;
                    }
                };
            }
        };
    }]).
    directive('scrollTo', ['$location','$anchorScroll',function ($location, $anchorScroll) {
        return function(scope, element, attrs) {
            element.bind('click', function (event) {
                event.stopPropagation();
                scope.$on('$locationChangeStart', function (ev) {
                    ev.preventDefault();
                });
                var location = attrs.scrollTo;
                $location.hash(location);
                $anchorScroll();
            });
        };
    }]);

angular.module('myServices',['ngResource']).
    factory('ApiLocal',['$resource',function($resource){
        return $resource('json/:file',
            {file:'@file'},
            {
                social: {method:'GET',params:{file:'socialIcons.json'},isArray:true},
                businessHours: {method:'GET',params:{file:'businessHours.json'},isArray:true},
                services: {method:'GET',params:{file:'services.json'},isArray:true}
            }
        );
    }]).
    factory('ApiRemote',['$resource',function($resource){
        return $resource('http://api.soundcorrections.com/drbollen/v1.0/:type/:id',
            {type:'@type',id:'@id'},
            {
                submit: {method:'POST',params:{type:'contact',id:'new'},isArray:false}
            }
        );
    }]).
    factory('Page', function(){
        var title = 'Dr. Ric Bollen, Upper Cervical Chiropractor',
            siteName = "Dr. Ric Bollen, Upper Cervical Chiropractor";
        return {
            title: function() { return title; },
            setTitle: function(newTitle,removeSiteName) {
                if(removeSiteName){
                    title = newTitle;
                }else{
                    title = siteName + ' | ' + newTitle;
                }
            }
        };
    });